==> haskell-should-not-typecheck-2.1.0-362-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-should-not-typecheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 should-not-typecheck
version:              2.1.0
visibility:           public
id:                   should-not-typecheck-2.1.0-AyWajPhi5A0AcZrbtW2Ayj
key:                  should-not-typecheck-2.1.0-AyWajPhi5A0AcZrbtW2Ayj
license:              BSD-3-Clause
maintainer:           message.me.on@github.com
author:               Callum Rogers
homepage:             http://github.com/CRogers/should-not-typecheck
synopsis:
    A HUnit/hspec assertion library to verify that an expression does not typecheck

description:
    For examples and an introduction to the library please take a look at the <https://github.com/CRogers/should-not-typecheck#should-not-typecheck- README> on github.

category:             Testing
abi:                  baa4a7cb9ff109c2496619ab8ef17b9a
exposed:              True
exposed-modules:      Test.ShouldNotTypecheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/should-not-typecheck-2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/should-not-typecheck-2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/should-not-typecheck-2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-should-not-typecheck
hs-libraries:         HSshould-not-typecheck-2.1.0-AyWajPhi5A0AcZrbtW2Ayj
depends:
    HUnit-1.6.2.0-IE0oFrOTEOHIkscEaBk8om base-4.18.2.1 deepseq-1.4.8.1

haddock-interfaces:
    /usr/share/doc/haskell-should-not-typecheck/html/should-not-typecheck.haddock

haddock-html:         /usr/share/doc/haskell-should-not-typecheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-should-not-typecheck-2.1.0-363-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-should-not-typecheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 should-not-typecheck
version:              2.1.0
visibility:           public
id:                   should-not-typecheck-2.1.0-G1BibiIWeJcETyWm2b4wuK
key:                  should-not-typecheck-2.1.0-G1BibiIWeJcETyWm2b4wuK
license:              BSD-3-Clause
maintainer:           message.me.on@github.com
author:               Callum Rogers
homepage:             http://github.com/CRogers/should-not-typecheck
synopsis:
    A HUnit/hspec assertion library to verify that an expression does not typecheck

description:
    For examples and an introduction to the library please take a look at the <https://github.com/CRogers/should-not-typecheck#should-not-typecheck- README> on github.

category:             Testing
abi:                  70b3f0f0d5b2b73fa99487481a2d7cc7
exposed:              True
exposed-modules:      Test.ShouldNotTypecheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/should-not-typecheck-2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/should-not-typecheck-2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/should-not-typecheck-2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-should-not-typecheck
hs-libraries:         HSshould-not-typecheck-2.1.0-G1BibiIWeJcETyWm2b4wuK
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA base-4.18.2.1 deepseq-1.4.8.1

haddock-interfaces:
    /usr/share/doc/haskell-should-not-typecheck/html/should-not-typecheck.haddock

haddock-html:         /usr/share/doc/haskell-should-not-typecheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
